@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -616,7 +616,7 @@ gm_tw_build_tab (GtkWidget *chat_window,
 					       GM_STOCK_STATUS_AVAILABLE,
 					       GTK_ICON_SIZE_MENU,
 					       _("Hang _up"),
-					       _("_Call user"));
+					       _("_Call"));
   gtk_tooltips_set_tip (tw->tips, twp->connect_button, _("Call this user"), 0); 
   gtk_box_pack_start (GTK_BOX (vbox), twp->connect_button, TRUE, FALSE, 0);
   
@@ -1136,6 +1136,7 @@ gm_tw_urls_history_update_cb (gpointer data)
 					      NULL,
 					      NULL,
 					      NULL,
+					      NULL,
 					      NULL);
   /* Get the full calls history */
   c2 = gm_calls_history_get_calls (MAX_VALUE_CALL, 25, TRUE, FALSE);
@@ -1378,8 +1379,6 @@ gm_text_chat_window_new ()
   
   GmTextChatWindow *tw = NULL;
 
-  gchar *filename = NULL;
-
   /* The window */
   chat_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   g_object_set_data_full (G_OBJECT (chat_window), "window_name",
@@ -1387,14 +1386,11 @@ gm_text_chat_window_new ()
   
   gtk_window_set_title (GTK_WINDOW (chat_window), _("Chat Window"));
 
-  filename = g_build_filename (DATA_DIR, "pixmaps", PACKAGE_NAME ".png", NULL);
-  pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-  g_free (filename);
-  if (pixbuf) {
-
-    gtk_window_set_icon (GTK_WINDOW (chat_window), pixbuf);
-    g_object_unref (pixbuf);
-  }
+  pixbuf = gtk_widget_render_icon (GTK_WIDGET (chat_window),
+				   GM_STOCK_16,
+				   GTK_ICON_SIZE_MENU, NULL);
+  gtk_window_set_icon (GTK_WINDOW (chat_window), pixbuf);
+  g_object_unref (pixbuf);
 
   gtk_window_set_position (GTK_WINDOW (chat_window), GTK_WIN_POS_CENTER);
 
