@@ -1,5 +1,5 @@
 
-/* GnomeMeeting -- A Video-Conferencing application
+/* Ekiga -- A VoIP and Video-Conferencing application
  * Copyright (C) 2000-2006 Damien Sandras
  *
  * This program is free software; you can redistribute it and/or modify
@@ -13,16 +13,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  *
- * GnomeMeting is licensed under the GPL license and as a special exception,
+ * Ekiga is licensed under the GPL license and as a special exception,
  * you have permission to link or otherwise combine this program with the
- * programs OpenH323 and Pwlib, and distribute the combination, without
- * applying the requirements of the GNU GPL to the OpenH323 program, as long
- * as you do follow the requirements of the GNU GPL for all the rest of the
- * software thus combined.
+ * programs OPAL, OpenH323 and PWLIB, and distribute the combination,
+ * without applying the requirements of the GNU GPL to the OPAL, OpenH323
+ * and PWLIB programs, as long as you do follow the requirements of the
+ * GNU GPL for all the rest of the software thus combined.
  */
 
 
@@ -50,6 +50,7 @@
 #include "gmdialog.h"
 
 #include "toolbox/toolbox.h"
+#include <gmstockicons.h>
 
 #ifdef WIN32
 #include "winpaths.h"
@@ -253,13 +254,13 @@ pc2phone_consult_cb (GtkWidget *widget,
     url = g_strdup ("https://www.diamondcard.us/exec/voip-login?act=sgn&spo=ekiga");
     break;
   case PC2PHONE_RECHARGE:
-    url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&passwordCode=%s&act=rch&spo=ekiga", account, password);
+    url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&pinCode=%s&act=rch&spo=ekiga", account, password);
     break;
   case PC2PHONE_HISTORY_BALANCE:
-    url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&passwordCode=%s&act=bh&spo=ekiga", account, password);
+    url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&pinCode=%s&act=bh&spo=ekiga", account, password);
     break;
   case PC2PHONE_HISTORY_CALLS:
-    url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&passwordCode=%s&act=ch&spo=ekiga", account, password);
+    url = g_strdup_printf ("https://www.diamondcard.us/exec/voip-login?accId=%s&pinCode=%s&act=ch&spo=ekiga", account, password);
     break;
   default:
     g_warning ("Invalid account link\n");
@@ -287,7 +288,6 @@ gm_pc2phone_window_new ()
 
   GdkPixbuf *pixbuf = NULL;
 
-  gchar *filename = NULL;
   gchar *txt = NULL;
   
 
@@ -311,15 +311,12 @@ gm_pc2phone_window_new ()
   
   gtk_window_set_title (GTK_WINDOW (window), _("PC-To-Phone Settings"));
   gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
-  filename = g_build_filename (DATA_DIR, "pixmaps", PACKAGE_NAME ".png", NULL);
-  pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-  g_free (filename);
+  pixbuf = gtk_widget_render_icon (GTK_WIDGET (window),
+				   GM_STOCK_16,
+				   GTK_ICON_SIZE_MENU, NULL);
+  gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
+  g_object_unref (pixbuf);
 
-  if (pixbuf) {
-
-    gtk_window_set_icon (GTK_WINDOW (window), pixbuf);
-    g_object_unref (pixbuf);
-  }
 
   /* Introduction label */
   label = gtk_label_new (_("You can make calls to regular phones and cell numbers worldwide using Ekiga. To enable this, you need to do three things. First create an account at the URL below. Then enter your account number and password. Finally, activate the registration below.\n\nThe service will work only if your account is created using the URL in this dialog."));
